@@ -366,7 +366,7 @@ def plot_scaled_boundary_overlay(
 
     if is_device(device, 'ITER'):
         dat = np.genfromtxt(os.sep.join([OMFITsrc, '..', 'samples', 'iter_BL2010_Gribov.txt']), skip_header=3)
-        r = dat[:, 0] * scale + x_offset
+        r = dat[:, 0] * abs(scale) + x_offset
         z = dat[:, 1] * scale + y_offset
         label = 'Scaled ITER'
     else:
