@@ -88,15 +88,15 @@ class OMFITGPECnc(OMFITncDataset):
     def _update_naming_conventions(self, version=None):
         """
 
-            Update the naming conventions in a dataset to the latest conventions.
+        Update the naming conventions in a dataset to the latest conventions.
 
-            Use this to avoid lots of if statements in cross-checking versions.
+        Use this to avoid lots of if statements in cross-checking versions.
 
-            :param dataset:
-            :param version: str. Override version attribute.
-            :return:
+        :param dataset:
+        :param version: str. Override version attribute.
+        :return:
 
-            """
+        """
         # set to operate on
         newset = copy.deepcopy(self)
 
@@ -429,6 +429,8 @@ def ascii_to_dataset(fname, squeeze=False, dims=(), excludedims=('l',), coords=(
             # choose some default squeeze dimensions
             if np.any(['isol' in ds.attrs for ds in collection]):
                 squeeze = 'isol'  # common in DCON
+            if np.any(['ia' in ds.attrs for ds in collection]):
+                squeeze = 'ia'  # used in EQUIL 2d.out
             else:
                 if np.any(['mode' in ds.attrs for ds in collection]):
                     squeeze = 'mode'  # common in GPEC
