@@ -544,7 +544,41 @@ class OMFITmdsConnectionBaseClass(SortedDict):
 
                 if what is not None:
                     if shot is not None:
-                        if treename is not None:
+                        if treename is not None and treename.upper() == 'PTDATA':
+                            printd(
+                                '* Retrieving remote data ' + pre + 'ptdata2("' + signal + '",' + shot + ')' + post,
+                                topic='MDS',
+                            )
+                            queryResult = mdsplus_data(
+                                self[mds_connection_cache_ID].get(pre + 'ptdata2("' + signal + '",' + shot + ')' + post, timeout=timeout)
+                            )
+
+                        elif treename is not None and treename.upper() == 'LOCAL_PTDATA':
+                            printd(
+                                '* Retrieving local data ' + pre + 'ptdata2("' + signal + '",' + shot + ')' + post,
+                                topic='MDS',
+                            )
+                            queryResult = mdsplus_data(MDSplus.TdiExecute(pre + 'ptdata2("' + signal + '",' + shot + ')' + post))
+
+                        elif treename is not None and treename.upper() == 'PSEUDO':
+                            printd('* Retrieving data ' + pre + 'pseudo("' + signal + '",' + shot + ')' + post, topic='MDS')
+                            queryResult = mdsplus_data(
+                                self[mds_connection_cache_ID].get(pre + 'pseudo("' + signal + '",' + shot + ')' + post, timeout=timeout)
+                            )
+
+                        elif treename is not None and treename.upper() == 'JETPPF':
+                            if '@' not in signal:
+                                signal = 'jetppf@' + signal
+                            directory, signal = signal.split('@')
+                            printd('* Retrieving data ' + pre + 'jet("' + signal + '",' + shot + ')' + post, topic='MDS')
+                            queryResult = mdsplus_data(
+                                self[mds_connection_cache_ID].get(
+                                    'ppfuid("' + directory + '");' + pre + 'jet("' + signal + '",' + shot + ')' + post,
+                                    timeout=timeout,
+                                )
+                            )
+
+                        elif treename is not None:
                             self[mds_connection_cache_ID].openTree(treename, int(shot))
                             try:
                                 queryResult = mdsplus_data(self[mds_connection_cache_ID].get(pre + signal + post, timeout=timeout))
@@ -556,10 +590,12 @@ class OMFITmdsConnectionBaseClass(SortedDict):
                                     return _special1
                                 else:
                                     raise
+
                         else:
                             try:
                                 queryResult = mdsplus_data(self[mds_connection_cache_ID].get(what, timeout=timeout))
                                 printd('* Retrieving data signal', topic='MDS')
+                            # everything below this line in this `else` statement is obsolescent
                             except Exception as _excp:
                                 printd(repr(_excp), topic='MDS')
 
@@ -574,6 +610,9 @@ class OMFITmdsConnectionBaseClass(SortedDict):
                                         )
                                     )
                                     printd('* Retrieving data ' + pre + 'jet("' + signal + '",' + shot + ')' + post, topic='MDS')
+                                    printd(
+                                        f"Use of treename=None for `{signal}` is deprecated; Please specify treename='JETPPF'", topic='MDS'
+                                    )
                                 else:
                                     try:
                                         try:
@@ -588,6 +627,10 @@ class OMFITmdsConnectionBaseClass(SortedDict):
                                                 '* Retrieving remote data ' + pre + 'ptdata2("' + signal + '",' + shot + ')' + post,
                                                 topic='MDS',
                                             )
+                                            printd(
+                                                f"Use of treename=None for `{signal}` is deprecated; Please specify treename='PTDATA'",
+                                                topic='MDS',
+                                            )
                                         except Exception as _excp:
                                             try:
                                                 queryResult = mdsplus_data(
@@ -597,6 +640,10 @@ class OMFITmdsConnectionBaseClass(SortedDict):
                                                     '* Retrieving local data ' + pre + 'ptdata2("' + signal + '",' + shot + ')' + post,
                                                     topic='MDS',
                                                 )
+                                                printd(
+                                                    f"Use of treename=None for `{signal}` is deprecated; Please specify treename='LOCAL_PTDATA'",
+                                                    topic='MDS',
+                                                )
                                             except Exception:
                                                 if 'Try local PTDATA' in repr(_excp):
                                                     pass
@@ -612,10 +659,14 @@ class OMFITmdsConnectionBaseClass(SortedDict):
                                                 )
                                             )
                                             printd('* Retrieving data ' + pre + 'pseudo("' + signal + '",' + shot + ')' + post, topic='MDS')
+                                            printd(
+                                                f"Use of treename=None for `{signal}` is deprecated; Please specify treename='PSEUDO'",
+                                                topic='MDS',
+                                            )
                                         except Exception as _excp:
                                             printd(repr(_excp), topic='MDS')
                                             raise MDSplus.MdsException(
-                                                'Failed to retrieve data from PTDATA: server=`%s` shot=`%s` what=`%s` [ %s ]'
+                                                'Failed to retrieve data from PTDATA/LOCAL_PTDATA/PSEUDO: server=`%s` shot=`%s` what=`%s` [ %s ]'
                                                 % (server, shot, what, repr(_excp))
                                             )
                     else:
@@ -624,12 +675,12 @@ class OMFITmdsConnectionBaseClass(SortedDict):
                             try:
                                 queryResult = mdsplus_data(self[mds_connection_cache_ID].get(what, timeout=timeout))
                                 if queryResult is not None and len(queryResult) == 1 and queryResult[0] == 0:
-                                    raise Exception('Try local PTDATA')
+                                    raise Exception('Try local TDI')
                             except Exception as _excp:
                                 try:
                                     queryResult = mdsplus_data(MDSplus.TdiExecute(what))
                                 except Exception:
-                                    if 'Try local PTDATA' in repr(_excp):
+                                    if 'Try local TDI' in repr(_excp):
                                         pass
                                     else:
                                         raise _excp
@@ -1034,10 +1085,10 @@ class OMFITmdsValue(dict, OMFITmdsObjects):
     The default resample function uses linear interpolation. To override it and use a different method, see
     http://www.mdsplus.org/index.php/Documentation:Users:LongPulseExtensions#Overriding_Re-sampling_Procedures
 
-    To access DIII-D PTDATA, set `treename=None` and use the `TDI` keyword to pass signal to be retrieved.
+    To access DIII-D PTDATA, set `treename='PTDATA'` and use the `TDI` keyword to pass signal to be retrieved.
     Note: PTDATA `ical` option can be passed by setting the `shot` keyword as a string with the shot number followed by the ical option separated by comma. e.g. shot='145419,1'
 
-    >> tmp=OMFITmdsValue('DIII-D', treename=None, shot=145419, TDI='ip')
+    >> tmp=OMFITmdsValue('DIII-D', treename='PTDATA', shot=145419, TDI='ip')
     >> x=tmp.dim_of(0)
     >> y=tmp.data()
     >> pyplot.plot(x,y)
@@ -1605,9 +1656,13 @@ def get_dss_radp_units(shot, pointname=None, latex_form=False):
     """
     Defines units for DS*RADP* signals
     These are not listed in PTDATA but they can be determined fairly easily; they should not be left blank
+
     :param shot: int
+
     :param pointname: string
+
     :param latex_form: bool (unused, but provided for consistency)
+
     :return: string
     """
     printd('keyword latex_form to get_dss_radp_units with value {} is ignored'.format(latex_form))
