@@ -5,7 +5,7 @@ except ImportError as _excp:
     # class is imported by itself
     if (
         'attempted relative import with no known parent package' in str(_excp)
-        or 'No module named \'omfit_classes\'' in str(_excp)
+        or 'No module named \'classes\'' in str(_excp)
         or "No module named '__main__.startup_choice'" in str(_excp)
     ):
         from startup_choice import *
@@ -14,15 +14,11 @@ except ImportError as _excp:
 
 import struct
 import numpy as np
-from omfit_classes.utils_plot import title_inside
-from matplotlib import pyplot, cm
-from omfit_classes.omfit_hdf5 import OMFIThdf5
-from scipy.interpolate import griddata
 
 __all__ = ['OMFITnimrod']
 
 
-class OMFITnimrod(OMFIThdf5):
+class OMFITnimrod(SortedDict, OMFITobject):
     r"""
     OMFIT class used to interface with NIMROD output files
     Note: does not support writing
@@ -33,7 +29,8 @@ class OMFITnimrod(OMFIThdf5):
     """
 
     def __init__(self, filename, **kw):
-        OMFIThdf5.__init__(self, filename, caseInsensitive=True)
+        OMFITobject.__init__(self, filename, **kw)
+        SortedDict.__init__(self, caseInsensitive=True)
         self.dynaLoad = True
 
     contour_labels = [
@@ -80,21 +77,26 @@ class OMFITnimrod(OMFIThdf5):
         'Im T_e [eV]',  # 41
         'T_i [eV]',  # 42
         'Im T_i [eV]',  # 43
-        'P_{rad} [W/m^3]',  # 44
-        'Im P_{rad} [W/m^3]',  # 45
-        'P_{iso} [W/m^3]',  # 46
-        'Im P_{iso} [W/m^3]',  # 47
-        'P_{ion} [W/m^3]',  # 48
-        'Im P_{ion} [W/m^3]',  # 49
-        'n_imp [m^{-3}]',  # 50
-        'Im n_imp [m^{-3}]',  # 51
-        'n_{inon} [m^{-3}]',  # 52
-        'Im n_{inon} [m^{-3}]',  # 53
-        'n_{neut} [m^{-3}]',  # 54
-        'Im n_{neut} [m^{-3}]',  # 55
-        'n_{imp neut} [m^{-3}]',  # 56
-        'n_{imp +1} [m^{-3}]',
-    ]  # 57
+        'P_{dilu} [W/m^3]',  # 44
+        'Im P_{dilu} [W/m^3]',  # 45
+        'P_{brem} [W/m^3]',  # 46
+        'Im P_{brem} [W/m^3]',  # 47
+        'P_{rec} [W/m^3]',  # 48
+        'Im P_{rec} [W/m^3]',  # 49
+        'P_{line} [W/m^3]',  # 50
+        'Im P_{line} [W/m^3]',  # 51
+        'P_{ion} [W/m^3]',  # 52
+        'Im P_{ion} [W/m^3]',  # 53
+        'n_imp [m^{-3}]',  # 54
+        'Im n_imp [m^{-3}]',  # 55
+        'n_{ele} [m^{-3}]',  # 56
+        'Im n_{ele} [m^{-3}]',  # 57
+        'n_{neut} [m^{-3}]',  # 58
+        'Im n_{neut} [m^{-3}]',  # 59
+        'n_{imp neut} [m^{-3}]',  # 60
+        'n_{imp +1} [m^{-3}]',  # 61
+        'n_{imp +2} [m^{-3}]',
+    ]  # 62
 
     discharge_labels = [
         'istep',
@@ -123,24 +125,6 @@ class OMFITnimrod(OMFIThdf5):
 
     flsurf_labels = ['t', 'ix', 'polm', 'sqrt(polm)', 'polp', 'sqrt(polp)', 'q_surf', 'par_surf']
 
-    fluxgrid_labels = [
-        'psi',
-        'F',
-        'mu0 P',
-        'q',
-        'mach',
-        'ne',
-        'mu0 P_e',
-        'mystery1',
-        'mystery2',
-        'mystery3',
-        'mystery4',
-        'mystery5',
-        'rho',
-        'jdotB/B^2',
-        'GS residual',
-    ]
-
     SPIhist_labels = ['thstp', 'thtm', 'ip', 'Rp', 'Zp', 'Pp', 'radius', 'aden', 'taden', 'eden', 'eT', 'ablt', 'tablt', 'asim', 'tsim']
 
     energy_labels = ['step', 'time', 'imode', 'k', 'E_mag', 'E_kin', 'prad']
@@ -381,16 +365,18 @@ class OMFITnimrod(OMFIThdf5):
         nybl = int(self['nybl'])
 
         if len(qnt.shape) == 3:
-            tmp = np.zeros((blx * nxbl, bly * nybl), dtype=qnt.dtype)
+            tmp = np.zeros(((blx - 1) * nxbl + 1, (bly - 1) * nybl + 1), dtype=qnt.dtype)
         elif len(qnt.shape) == 4:
-            tmp = np.zeros((blx * nxbl, bly * nybl, qnt.shape[2]), dtype=qnt.dtype)
+            tmp = np.zeros(((blx - 1) * nxbl + 1, (bly - 1) * nybl + 1, qnt.shape[2]), dtype=qnt.dtype)
 
         for ibl in range(nxbl):
             for jbl in range(nybl):
                 if len(qnt.shape) == 3:
-                    tmp[ibl * blx : (ibl + 1) * blx, jbl * bly : (jbl + 1) * bly] = qnt[:, :, nybl * ibl + jbl]
+                    tmp[ibl * (blx - 1) : ibl * (blx - 1) + blx, jbl * (bly - 1) : jbl * (bly - 1) + bly] = qnt[:, :, nybl * ibl + jbl]
                 elif len(qnt.shape) == 4:
-                    tmp[ibl * blx : (ibl + 1) * blx, jbl * bly : (jbl + 1) * bly, :] = qnt[:, :, :, nybl * ibl + jbl]
+                    tmp[ibl * (blx - 1) : ibl * (blx - 1) + blx, jbl * (bly - 1) : jbl * (bly - 1) + bly, :] = qnt[
+                        :, :, :, nybl * ibl + jbl
+                    ]
 
         return tmp
 
@@ -459,7 +445,7 @@ class OMFITnimrod(OMFIThdf5):
                 else:
                     self[label] = self._merge_blocks(varr[:, :, :, :, k])
 
-    def _plot_contour(self, label=None, overlay_grid=False, slice=0, phase=0, nlevels=21):
+    def _plot_contour(self, slice=0, phase=0, nlevels=21):
         """
         Default plot for contour.bin files
 
@@ -469,58 +455,27 @@ class OMFITnimrod(OMFIThdf5):
 
         :param nlevels: number of levels in the contours
         """
-
         plts = np.array([31, 35, 41, 13, 14, 15, 19, 20, 21, 25, 26, 27])
-        pyplot.ioff()
+        ioff()
         try:
-            if label is not None:
-                ndump = np.size(self['B_r [T]'], 2)
-
-                for js in range(ndump):
-                    if ndump == 1:
-                        ax = pyplot.subplot(1, 1, 1)
-                    elif ndump == 2:
-                        ax = pyplot.subplot(1, 2, js + 1)
-                    else:
-                        ax = pyplot.subplot((ndump - 1) // 3 + 1, min(3, ndump), js + 1)
-
-                    self._plot_single_contour(overlay_grid=overlay_grid, label=label, slice=js, phase=phase, nlevels=nlevels)
-                    ax.set_title('n = ' + str(js))
-
-            else:
-                for k, label in enumerate(np.array(self.contour_labels)[plts]):
-                    if k == 0:
-                        ax = pyplot.subplot(3, 4, k + 1)
-                    else:
-                        pyplot.subplot(3, 4, k + 1, sharex=ax, sharey=ax)
-
-                    self._plot_single_contour(overlay_grid=overlay_grid, label=label, slice=slice, phase=phase, nlevels=nlevels)
-                pyplot.suptitle('Contour Summary', fontsize=18)
-                pyplot.tight_layout(rect=[0, 0.03, 1, 0.95])
+            for k, label in enumerate(np.array(self.contour_labels)[plts]):
+                if k == 0:
+                    ax = pyplot.subplot(3, 4, k + 1)
+                else:
+                    pyplot.subplot(3, 4, k + 1, sharex=ax, sharey=ax)
+                if 'complex' in self[label].dtype.name and phase != 0:
+                    contour(self['r'], self['z'], np.real(self[label][:, :, slice] * np.exp(1j * phase)), nlevels)
+                else:
+                    contour(self['r'], self['z'], self[label][:, :, slice], nlevels)
+                pyplot.title('$' + re.sub(r'\(', '\\,(', label) + '$')
+                pyplot.gca().set_aspect('equal')
+                pyplot.plot(self['r'][-1, :], self['z'][-1, :], 'k')
+            autofmt_sharexy()
+            pyplot.subplots_adjust(wspace=0.0, hspace=0.2)
+            pyplot.suptitle('Slice ' + str(slice))
         finally:
-            pyplot.ion()
-            pyplot.show()
-
-    def _plot_single_contour(self, grid_alpha=0.15, overlay_grid=False, label=None, slice=0, phase=0, nlevels=21):
-
-        fig = pyplot.gcf()
-        ax = pyplot.gca()
-        if 'complex' in self[label].dtype.name and phase != 0:
-            cs = ax.contourf(self['r'], self['z'], np.real(self[label][:, :, slice] * np.exp(1j * phase)), nlevels)
-        else:
-            cs = ax.contourf(self['r'], self['z'], self[label][:, :, slice], nlevels)
-
-        ax.plot(self['r'][-1, :], self['z'][-1, :], 'k', lw=1.5)
-
-        if overlay_grid:
-            ax.plot(self['r'], self['z'], color='k', alpha=grid_alpha)
-            ax.plot(self['r'].transpose(), self['z'].transpose(), color='k', alpha=grid_alpha)
-
-        fig.colorbar(cs)
-        ax.set_xlabel('R[m]', fontsize=14)
-        ax.set_ylabel('Z[m]', fontsize=14)
-        ax.set_title('$' + re.sub(r'\(', '\\,(', label) + '$')
-        ax.set_aspect('equal')
+            ion()
+            show()
 
     def _read_polflux(self):
         """
@@ -537,17 +492,21 @@ class OMFITnimrod(OMFIThdf5):
 
         R = self['R'] = np.reshape(cdata[2][: mx * my], (my, mx))
         Z = self['Z'] = np.reshape(cdata[2][mx * my :], (my, mx))
-
-        polflux = self['polflux'] = np.reshape(cdata[3][:], (my, mx))
-
-        RBphi = self['R*Bphi'] = np.reshape(cdata[4][:], (my, mx))
+        self['polflux'] = np.ndarray([my, mx, (len(cdata) - 3) // 2])
+        self['R*Bphi'] = np.ndarray([my, mx, (len(cdata) - 3) // 2])
+        nd = 3
+        while nd + 1 < len(cdata):
+            polflux = self['polflux'][:, :, (nd - 3) // 2] = np.reshape(cdata[nd][:], (my, mx))
+            nd = nd + 1
+            RBphi = self['R*Bphi'][:, :, (nd - 4) // 2] = np.reshape(cdata[nd][:], (my, mx))
+            nd = nd + 1
 
     def _plot_polflux(self):
         """
         Default plot for polflux.bin files
 
         """
-        pyplot.ioff()
+        ioff()
         try:
             ax = pyplot.subplot(1, 2, 1)
             contourf(self['R'], self['Z'], self['polflux'])
@@ -555,11 +514,11 @@ class OMFITnimrod(OMFIThdf5):
             pyplot.subplot(1, 2, 2, sharey=ax)
             contourf(self['R'], self['Z'], self['R*Bphi'])
             pyplot.title('R*Bphi')
-            pyplot.suptitle('polflux Summary', fontsize=18)
-            pyplot.tight_layout(rect=[0, 0.03, 1, 0.95])
+            autofmt_sharexy()
+            pyplot.subplots_adjust(wspace=0.0, hspace=0.2)
         finally:
-            pyplot.ion()
-            pyplot.show()
+            ion()
+            show()
 
     def _read_flsurf(self):
         """
@@ -572,19 +531,19 @@ class OMFITnimrod(OMFIThdf5):
             self[label] = cdata[0, :, k]
 
     def _plot_flsurf(self):
-        """ion()
+        """
         Default plot for flsurf.bin files
 
         """
-        pyplot.ioff()
+        ioff()
         try:
             pyplot.plot(self['polp'], self['q_surf'], label='q_surf')
             pyplot.plot(self['polp'], self['par_surf'], label='par_surf')
             pyplot.title('q and j|| vs poloidal flux')
             legend()
         finally:
-            pyplot.ion()
-            pyplot.show()
+            ion()
+            show()
 
     def _read_discharge(self):
         """
@@ -594,7 +553,7 @@ class OMFITnimrod(OMFIThdf5):
 
         discharge_labels = self.discharge_labels[: alld.shape[-1]]
         for kit, it in enumerate(discharge_labels):
-            if it not in ['istep', 'dummy', 'lnE', 'lnIE']:
+            if it not in ['dummy', 'lnE', 'lnIE']:
                 try:
                     self[it] = np.squeeze(alld)[:, kit]
                 except IndexError as _excp:
@@ -616,9 +575,8 @@ class OMFITnimrod(OMFIThdf5):
                 pyplot.plot(self['time'] * 1e3, self[it])
                 title_inside(it, 0.5, 0.7)
                 pyplot.xlabel('time [ms]')
-
-        pyplot.suptitle('Discharge Summary', fontsize=18)
-        pyplot.tight_layout(rect=[0, 0.03, 1, 0.95])
+        autofmt_sharex()
+        pyplot.suptitle('Discharge summary')
 
     def _read_kpraden(self):
         """
@@ -645,9 +603,8 @@ class OMFITnimrod(OMFIThdf5):
                 pyplot.plot(self['time'] * 1e3, self[it])
                 title_inside(it, 0.5, 0.7)
                 pyplot.xlabel('time [ms]')
-
-        pyplot.suptitle('kprad Energy Summary', fontsize=18)
-        pyplot.tight_layout(rect=[0, 0.03, 1, 0.95])
+        autofmt_sharex()
+        pyplot.suptitle('kprad radiation')
 
     def _read_kpradnz(self):
         """
@@ -674,9 +631,8 @@ class OMFITnimrod(OMFIThdf5):
                 pyplot.plot(self['time'] * 1e3, self[it])
                 title_inside(it, 0.5, 0.7)
                 pyplot.xlabel('time [ms]')
-
-        pyplot.suptitle('kprad impurities Summary', fontsize=18)
-        pyplot.tight_layout(rect=[0, 0.03, 1, 0.95])
+        autofmt_sharex()
+        pyplot.suptitle('kprad impurities')
 
     def _read_energy(self):
         """
@@ -713,18 +669,18 @@ class OMFITnimrod(OMFIThdf5):
         ax2 = pyplot.subplot(2, 1, 2, sharex=ax1)
         pyplot.ylabel('$E_{\\rm kin}$')
 
+        autofmt_sharex()
+
         for k in range(len(self['modes_k'])):
             ax1.semilogy(self['time'] * 1e3, self[k]['E_mag'], label=str(self['modes_k'][k]), color=colors[k])
 
         for k in range(len(self['modes_k'])):
             ax2.semilogy(self['time'] * 1e3, self[k]['E_kin'], label=str(self['modes_k'][k]), color=colors[k])
+        ax2.legend(loc=0).draggable(True)
 
         pyplot.xlim([0, max(self['time'] * 1e3)])
         pyplot.xlabel('time [ms]')
 
-        pyplot.suptitle('Energy Summary', fontsize=18)
-        pyplot.tight_layout(rect=[0, 0.03, 1, 0.95])
-
     def _plot_prad(self):
         """
         Prad plot for energy.bin files
@@ -801,8 +757,8 @@ class OMFITnimrod(OMFIThdf5):
                 pyplot.ylabel('iy/my')
             pyplot.title(label)
 
-        pyplot.suptitle('xy-slice Summary', fontsize=18)
-        pyplot.tight_layout(rect=[0, 0.03, 1, 0.95])
+        autofmt_sharexy()
+        pyplot.subplots_adjust(wspace=0.0, hspace=0.2)
 
     def _read_xt_slice(self):
         """
@@ -867,8 +823,8 @@ class OMFITnimrod(OMFIThdf5):
             if k == 1:
                 pyplot.gca().legend(self)
 
-        pyplot.suptitle('xt-slice Summary', fontsize=18)
-        pyplot.tight_layout(rect=[0, 0.03, 1, 0.95])
+        autofmt_sharex()
+        pyplot.subplots_adjust(wspace=0.3, hspace=0.2)
 
     def _read_nimhist(self):
         """
@@ -896,36 +852,7 @@ class OMFITnimrod(OMFIThdf5):
         alld = self._read_table()
         SPIhist_labels = self.SPIhist_labels[: alld.shape[-1]]
         for kit, it in enumerate(SPIhist_labels):
-            if it not in ['istep']:
-                self[it] = np.squeeze(alld)[:, kit]
-
-    def _read_fluxgrid(self):
-        """
-        Parse fluxgrid.bin files
-        """
-        alld = self._read_table()
-        fluxgrid_labels = self.fluxgrid_labels[: alld.shape[-1]]
-        for kit, it in enumerate(fluxgrid_labels):
-            self[it] = np.squeeze(alld)[:, kit]
-
-    def _plot_fluxgrid(self):
-        """
-        Default plot for fluxgrid.bin files
-        """
-        kit = 0
-        for it in self:
-            if it not in ['psi', 'rho', 'mach', 'mu0 P_e'] and 'mystery' not in it:
-                kit += 1
-                if kit == 1:
-                    ax = pyplot.subplot(2, 3, kit)
-                else:
-                    pyplot.subplot(2, 3, kit, sharex=ax)
-                pyplot.plot(self['rho'], self[it])
-                title_inside(it, 0.5, 0.7)
-                pyplot.xlabel(r'$\rho$')
-
-        pyplot.suptitle('Fluxgrid Summary', fontsize=18)
-        pyplot.tight_layout(rect=[0, 0.03, 1, 0.95])
+            self[it] = alld[:, :, kit]
 
     def _plot_nimhist(self, nlevels=21):
         """
@@ -952,9 +879,11 @@ class OMFITnimrod(OMFIThdf5):
                     pass
             pyplot.xlabel('t')
             pyplot.title(tlabel)
+            if k == 1:
+                pyplot.gca().legend(self).draggable()
 
-        pyplot.suptitle('Nimrod History', fontsize=18)
-        pyplot.tight_layout(rect=[0, 0.03, 1, 0.95])
+        autofmt_sharex()
+        pyplot.subplots_adjust(wspace=0.3, hspace=0.2)
 
     def _read_nimfl(self):
         """
@@ -979,43 +908,6 @@ class OMFITnimrod(OMFIThdf5):
         pyplot.gca().set_aspect('equal')
         pyplot.ylim([limits['zmin'], limits['zmax']])
 
-    def _plot_dumph5_single_contour(self, field_name='rete', slice=0, rmin=None, rmax=None, zmin=None, zmax=None, grid_size=200):
-
-        rblocks = self['rblocks']
-        vals = np.zeros(0)
-        r = np.zeros(0)
-        z = np.zeros(0)
-        for block in rblocks:
-            r = np.concatenate((r, rblocks[block]['rz' + block]['data'][:, :, 0].flatten()))
-            z = np.concatenate((z, rblocks[block]['rz' + block]['data'][:, :, 1].flatten()))
-            vals = np.concatenate((vals, rblocks[block][field_name + block]['data'][:, :, slice].flatten()))
-
-        if zmin is None:
-            zmin = np.min(z)
-        if zmax is None:
-            zmax = np.max(z)
-        if rmin is None:
-            rmin = np.min(r)
-        if rmax is None:
-            rmax = np.max(r)
-
-        grid_r, grid_z = np.meshgrid(np.linspace(rmin, rmax, grid_size), np.linspace(zmin, zmax, grid_size))
-
-        points = np.array([r, z]).transpose()
-        grid_vals = griddata(points, vals, (grid_r, grid_z), method='cubic')
-
-        ax = pyplot.gca()
-        fig = pyplot.gcf()
-        cs = ax.contourf(grid_r, grid_z, grid_vals)
-
-        fig.colorbar(cs)
-        ax.set_xlabel('R[m]', fontsize=14)
-        ax.set_ylabel('Z[m]', fontsize=14)
-        ax.set_aspect('equal')
-
-        pyplot.suptitle(field_name + ' Contour', fontsize=18)
-        pyplot.tight_layout(rect=[0, 0.03, 1, 0.95])
-
     @dynaLoad
     def load(self):
         if 'energy' in os.path.split(self.filename)[1]:
@@ -1026,8 +918,6 @@ class OMFITnimrod(OMFIThdf5):
             self._read_kpraden()
         elif 'kpradnz' in os.path.split(self.filename)[1]:
             self._read_kpradnz()
-        elif 'fluxgrid' in os.path.split(self.filename)[1]:
-            self._read_fluxgrid()
         elif 'flsurf' in os.path.split(self.filename)[1]:
             self._read_flsurf()
         elif 'polflux' in os.path.split(self.filename)[1]:
@@ -1052,12 +942,10 @@ class OMFITnimrod(OMFIThdf5):
             self._read_nimhist()
         elif 'SPIhist' in os.path.split(self.filename)[1]:
             self._read_SPIhist()
-        elif 'dump' in os.path.split(self.filename)[1] and 'h5' in os.path.split(self.filename)[1]:
-            super().load()
         else:
             self['data'] = self._read_table()
 
-    def plot(self, figsize=None, label=None, overlay_grid=False, slice=0, phase=0, nlevels=21):
+    def plot(self, slice=0, phase=0, nlevels=21):
         """
         Default plot of energy.bin, discharge.bin, contour.bin and grid.bin files
 
@@ -1067,10 +955,6 @@ class OMFITnimrod(OMFIThdf5):
 
         :param nlevels: (contour.bin) number of levels in the contours
         """
-        if figsize is not None:
-            fig = pyplot.gcf()
-            fig.set_figheight(figsize[1])
-            fig.set_figwidth(figsize[0])
         if 'energy' in os.path.split(self.filename)[1]:
             self._plot_energy()
         elif 'discharge' in os.path.split(self.filename)[1]:
@@ -1081,12 +965,10 @@ class OMFITnimrod(OMFIThdf5):
             self._plot_kpradnz()
         elif 'flsurf' in os.path.split(self.filename)[1]:
             self._plot_flsurf()
-        elif 'fluxgrid' in os.path.split(self.filename)[1]:
-            self._plot_fluxgrid()
         elif 'polflux' in os.path.split(self.filename)[1]:
             self._plot_polflux()
         elif 'contour' in os.path.split(self.filename)[1]:
-            self._plot_contour(overlay_grid=overlay_grid, label=label, slice=slice, phase=phase, nlevels=nlevels)
+            self._plot_contour(slice=slice, phase=phase, nlevels=nlevels)
         elif 'conrz' in os.path.split(self.filename)[1]:
             self._plot_contour(slice=slice, phase=phase, nlevels=nlevels)
         elif 'grid' in os.path.split(self.filename)[1]:
